(define-module (ui bird ajax)
    :use-module (alterator ajax)
    :use-module (alterator str)
    :use-module (alterator woo)
    :use-module (alterator effect)
    :export (init))

; DEBUG STRING (PASTE IN FOR YOUR NEEDS).
; (format #t "XXX: ~S\n" rdp_profile_name)
; (format #t "[ajax, module] action info\n")

; TO DEBUG DO:
; 1) define *debug* to #t
; 2) start ahttpd -l -d
(define *debug* #f)
(define (dmsg msg . args)
  (if *debug*
    (format #t "[ajax, bird]: ~S ~S\n" msg args)))


; TURN OFF
(define (write-off)

  (dmsg "write-off() -- enter")

  (catch/message
    (lambda()
      (woo-write "/bird/off"
                 'language (form-value "language"))))
  (read-current-status))


; TURN ON
(define (write-on)

  (dmsg "write-on() -- enter")

  (catch/message
    (lambda()
      (woo-write "/bird/on"
                 'language (form-value "language"))))
  (read-current-status))


; SAVE SETTINGS
(define (write-save)

  (dmsg "write-save() -- enter")

  (catch/message
    (lambda()
      (apply woo-write "/bird/save"
             'language (form-value "language")
             (form-value-list))
      (read-current-status))))


; RESET ALL VALUES
(define (widgets-reset)

  (dmsg "Reset all widgets\n")

  (for-each (lambda(p) (form-update-value p ""))
            '("config"
              "information"))

  (for-each (lambda(p) (form-update-visibility p #f))
            '("btn-start"
              "btn-stop"))

  (for-each (lambda(p) (form-update-value p #f))
            '("chkbox_autostart")))


; UPDATE WIDGETS STATUS
(define (widgets-update)

  (dmsg "Update widgets status\n"))


; READ CURRENT SETTINGS
(define (read-current-status)

  (dmsg "read-current-status() -- enter\n")

  (and

    ; RESET WIDGETS
    (widgets-reset)

    ; FILL LISTS
    (for-each
      (lambda(lst)
        (form-update-enum lst
                          (woo-list
                            (string-append "/bird/" lst)
                            'language (form-value "language"))))
      '("list_status"))

    ; REBIND ACTIONS ON LISTS
    ;;(form-bind "list_z_type" "change" foo)

    ; READ CURRENT SETTINGS
    (let* ((settings
             (woo-read-first "/bird/status"
                             'language (form-value "language")))
           (current_status (woo-get-option settings 'current_status "off")))

      ; FILL WIDGETS
      (form-update-value-list settings)

      ; CONFIGURATION STATUS
      (form-update-visibility "btn-start" (if (string-ci=? current_status "on") #f #t))
      (form-update-visibility "btn-stop" (if (string-ci=? current_status "off") #f #t)))

    ; UPDATE WIDGETS STATUS
    (widgets-update)))


; UPLOAD NEW CONFIG
(define (cfg-upload)

  (dmsg "cfg-upload() -- enter\n")

  (if (not (string-null? (form-value "file_config")))
    (call-with-form-file "file_config"
                         (lambda(path)
                           (catch/message
                             (lambda()
                               (woo "newconfig" "/bird"
                                    'path_cfg path
                                    'language (form-value "language")))))))

  (if (not (string-null? (form-value "file_config")))
    (read-current-status)))


; DOWNLOAD CURRENT CONFIG
(define (cfg-download) 

  (dmsg "cfg-download() -- enter\n")

  (form-replace "/bird/download_cfg"))


; CHANGE START AT BOOT
(define (ui-change-bootstart)
  (dmsg "ui-change-bootstart() -- enter\n")

  (woo-call "/bird/change_bootstart" 'onoff (form-value "chkbox_autostart")))

; INITIALIZATION ROUTINE
(define (init)

  (dmsg "init() -- enter")

  ; INTERCONNECT BUTTON WITH ACTION
  (form-bind "btn-start" "click" write-on)
  (form-bind "btn-stop" "click" write-off)
  (form-bind "btn-save" "click" write-save)
  (form-bind "btn-reset" "click" read-current-status)

  ; DOWNLOAD / UPLOAD CONFIG FILE
  (form-bind "btn-download" "click" cfg-download)
  (form-bind-upload "btn-upload" "click" "file_config" cfg-upload)

  ; AUTO HIDE AREAS
  (effect-show "information" "chk_box_info" #t)
  (init-effect)

  ; LIST CHANGE
  ;(form-bind "list_onoff" "change" update-ui)

  ; CHECKBOX CHANGE
  (form-bind "chkbox_autostart" "change" ui-change-bootstart)

  ; INTERFACE INITIALIZATION
  (read-current-status))

; vim: ft=lisp expandtab
